@@ -18,30 +18,17 @@ int main(int, char **)
 //	inject_property<SelfNonCommuting>(k, "{A,B,C,D }");
 //	inject_property<Trace>(k, "tr{#}");
 
-	// Scalar broadcast
-	NTensor t3a( { 2.0 } );
-	std::cerr << "t3a.shape.size() = " << t3a.shape.size() << std::endl;
-	std::cerr << "t3a.shape[0]     = " << t3a.shape[0] << std::endl;	
-	NTensor t432a=t3a.broadcast( {4, 1}, 1 );
-	std::cerr << t432a << std::endl;
-
 	// NTensor broadcast
 	NTensor t3( { 1.0, 2.0, 3.0 } );
 	NTensor t432=t3.broadcast( {4,3,2}, 1 );
 	std::cerr << t432 << std::endl;
 
-	NTensor t3c( { 1.0, 2.0, 3.0 } );
-	NTensor t432c1=t3c.broadcast( {3,3,2}, 1 );
-	std::cerr << t432c1 << std::endl;
-	NTensor t432c2=t3c.broadcast( {3,3,2}, 0 );
-	std::cerr << t432c2 << std::endl;
-
 
 	// Multiplying two scalar variables which each take
 	// an array of values leads to an outer product.
 
 	auto ex1b = "B*A + A"_ex(k);
-	NEvaluator ev1b(ex1b->begin());
+	NEvaluator ev1b(*ex1b);
 	ev1b.set_variable(Ex("A"), NTensor({1.0, 2.0, 3.0}));
 	ev1b.set_variable(Ex("B"), NTensor({0.5, 1.0, 5.0, 10.0}));
 	// This should give a {3, 4} tensor.
@@ -49,7 +36,7 @@ int main(int, char **)
 	std::cout << "B*A + A = " << res1b << "\n\n";
 
 	auto ex1 = "B*A + C"_ex(k);
-	NEvaluator ev1(ex1->begin());
+	NEvaluator ev1(*ex1);
 	ev1.set_variable(Ex("A"), NTensor({1.0, 2.0, 3.0}));
 	ev1.set_variable(Ex("B"), NTensor({0.5, 1.0, 5.0, 10.0}));
 	ev1.set_variable(Ex("C"), NTensor({1.0, -1.0}));
@@ -68,7 +55,7 @@ int main(int, char **)
 	std::cout << "\n\n";
 	std::cout << nt2 << std::endl;
 
-	NEvaluator ev(ex2->begin());
+	NEvaluator ev(*ex2);
 	ev.set_variable(Ex("C"), { 3.0 });
 	ev.set_variable(Ex("B"), { 2.3 });
 	ev.set_variable(Ex("A"), { 1.2 });
@@ -78,17 +65,13 @@ int main(int, char **)
 	// Double trig.
 	Stopwatch sw;
 	auto ex3 = R"( \cos(x) \sin(y) )"_ex(k);
-	NEvaluator ev3(ex3->begin());
+	NEvaluator ev3(*ex3);
 	ev3.set_variable(Ex("x"), NTensor::linspace(0.0, 3.14, 1000));
 	ev3.set_variable(Ex("y"), NTensor::linspace(0.0, 3.14, 1000));
 	sw.start();
-	int num=100;
-	for(int i=0; i<num; ++i) {
-		auto res3 = ev3.evaluate();
-		}
+	auto res3 = ev3.evaluate();
 	sw.stop();
-	sw /= num;
-	std::cout << "cos(x) sin(y) over a 1000x1000 grid took " << sw << " on average\n\n";
+	std::cout << "cos(x) sin(y) over a 1000x1000 grid took " << sw << "\n\n";
 
 	// Array indexing.
 
@@ -96,6 +79,4 @@ int main(int, char **)
 	nt.at({1,2,0}) = 6.2830;
 	nt.at({0,3,2}) = -6.2830;
 	std::cout << nt << std::endl;
-
-	std::cout << "is this real? " << nt.is_real() << std::endl;
 	}
