@@ -1,5 +1,3 @@
-import base64
-
 def _latex_post_parser(text):
     return (
         text.replace("\\begin{dmath*}", "$")
@@ -13,14 +11,12 @@ class Server:
     def __init__(self, kernel_instance):
         self._kernel = kernel_instance
 
-    def send(self, data, typestr, parent_id, cell_id, last_in_sequence):
+    def send(self, data, typestr, parent_id, last_in_sequence):
         if typestr == "latex_view":
             data = _latex_post_parser(data)
             self._kernel._send_result(data)
-        elif typestr == "image_svg":
-            self._kernel._send_image(base64.b64decode(data), "svg+xml")
         elif typestr == "image_png":
-            self._kernel._send_image(data, "png")
+            self._kernel._send_image(data)
         elif typestr == "verbatim":
             self._kernel._send_code(data)
         elif typestr == "input_form":
@@ -37,7 +33,7 @@ class Server:
         self._kernel._send_result("Test: We've gone on holiday by mistake!")
 
     def handles(self, otype):
-        if otype == "latex_view" or otype == "image_png" or otype=="image_svg" or otype == "verbatim":
+        if otype == "latex_view" or otype == "image_png" or otype == "verbatim":
             return True
         return False
 
